==> NPhish-0.1.5.tar.gz: NPhish-0.1.5/README.md <==
<h1 align="center">NPhish</h1>

### [+] Description :

***Ultimate phishing tool in python. Includes popular websites like facebook, twitter, instagram, github, reddit, gmail and many others.***

### [+] Installation

##### Install primary dependencies (git and python)

 - For Debian
    - ```sudo apt install git python -y```
 - For Arch
    - ```sudo pacman -S git python --noconfirm```
 - For Fedora
    - ```sudo yum install git python -y```
 - For Termux
    - ```pkg install git python -y```

##### Install this tool

 - ```pip install NPhish```

##### Run the tool
 - ```NPhish```

#### Or, directly run
```
pip install NPhish && NPhish

```

### Features:

 - Multi platform (Supports most linux)
 - 65 Website templates for 50+ sites.
 - Dual Tunneling (Ngrok and Cloudflared)
 - Easy to use
 - Possible error diagnoser
 - Built-in masking of url
 - Custom masking of url
 - Portable file (Can be run from any directory)
 - Get IP Address and many other details along with login credentials

### Requirements

 - `Active Internet Connection`
 - `Python(3)`
 - `PHP`
 - `Curl`
 - `Unzip`
 - `Wget`
 
If not found, all of the required packages will be installed on first run

#### Tested on

 - `Termux`
 - `Kali-Linux`

## Usage

1. Run the Tool
2. Choose a Website
3. Wait sometimes for setting up all
4. Send the generated link to victim
5. Wait for victim login. As soon as he/she logs in, credentials will be captured.

## [+] Disclaimer
***This tool is developed for educational purposes. Here it demonstrates how phishing works. If anybody wants to gain unauthorized access to someones social media, he/she may try out this at his/her own risk. You have your own responsibilities and you are liable to any damage or violation of laws by this tool. The author is not responsible for any misuse of NPhish!***

### This repository is open source to help others. So if you wish to copy, consider giving credit !!!

####  If this tool helped you, consider staring repository on github . Your stars encourage me a lot !!!


## GitHub Link : 
 
 ```https://github.com/Nishant2009/NPhish```

==> NPhish-0.1.7.0.0.0.0.1.tar.gz: NPhish-0.1.7.0.0.0.0.1/README.md <==
<h1 align="center">NPhish</h1>

### [+] Description :

***Ultimate phishing tool in python. Includes popular websites like facebook, twitter, instagram, github, reddit, gmail and many others.***

### [+] Installation

##### Install primary dependency (python)

 - For Debian
    - ```sudo apt install python -y```
 - For Arch
    - ```sudo pacman -S python --noconfirm```
 - For Fedora
    - ```sudo yum install python -y```
 - For Termux
    - ```pkg install python -y```

##### Install this tool

 - ```pip install NPhish```

##### Run the tool
 - ```NPhish```

#### Or, directly run
```
pip install NPhish && NPhish

```

### Features:

 - Multi platform (Supports most linux)
 - 65 Website templates for 50+ sites.
 - Fast Tunneling (via Cloudflared)
 - Easy to use
 - Possible error diagnoser
 - Built-in masking of url
 - Custom masking of url
 - Portable file (Can be run from any directory)
 - Get IP Address and many other details along with login credentials

### Requirements

 - `Active Internet Connection`
 - `Python(3)`
 - `PHP`
 
If not found, all of the required packages will be installed on first run

#### Tested on

 - `Termux`
 - `Kali-Linux`

## Usage

1. Run the Tool
2. Choose a Website
3. Wait sometimes for setting up all
4. Send the generated link to victim
5. Wait for victim login. As soon as he/she logs in, credentials will be captured.

## [+] Disclaimer
***This tool is developed for educational purposes. Here it demonstrates how phishing works. If anybody wants to gain unauthorized access to someones social media, he/she may try out this at his/her own risk. You have your own responsibilities and you are liable to any damage or violation of laws by this tool. The author is not responsible for any misuse of NPhish!***

### This repository is open source to help others. So if you wish to copy, consider giving credit !!!

####  If this tool helped you, consider staring repository on github . Your stars encourage me a lot !!!


## GitHub Link : 
 
 ```https://github.com/Nishant2009/NPhish```
